==> kmymoney-5.1.92.tar.xz: kmymoney-5.1.92/kmymoney/plugins/icalendar/export/icalendarexporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "onet.cristian@gmail.com",
                "Name": "Cristian Oneț",
                "Name[ca@valencia]": "Cristian Oneț",
                "Name[ca]": "Cristian Oneț",
                "Name[cs]": "Cristian Oneț",
                "Name[de]": "Cristian Oneț",
                "Name[en_GB]": "Cristian Oneț",
                "Name[eo]": "Cristian Oneț",
                "Name[es]": "Cristian Oneț",
                "Name[et]": "Cristian Oneț",
                "Name[eu]": "Cristian Oneț",
                "Name[fi]": "Cristian Oneț",
                "Name[fr]": "Cristian Oneț",
                "Name[gl]": "Cristian Oneț",
                "Name[ia]": "Cristian Oneț",
                "Name[it]": "Cristian Oneț",
                "Name[ka]": "Cristian Oneț",
                "Name[ko]": "Cristian Oneț",
                "Name[nb]": "Cristian Oneț",
                "Name[nl]": "Cristian Oneț",
                "Name[pl]": "Cristian Oneț",
                "Name[pt]": "Cristian Oneț",
                "Name[pt_BR]": "Cristian Oneț",
                "Name[ru]": "Cristian Oneț",
                "Name[sk]": "Cristian Oneț",
                "Name[sl]": "Cristian Oneț",
                "Name[sv]": "Cristian Oneț",
                "Name[tr]": "Cristian Oneț",
                "Name[uk]": "Cristian Oneț",
                "Name[x-test]": "xxCristian Onețxx",
                "Name[zh_CN]": "Cristian Oneț",
                "Name[zh_TW]": "Cristian Oneț"
            }
        ],
        "Description": "Exports schedules to iCalendar files",
        "Description[ca@valencia]": "Exporta les planificacions a fitxers iCalendar",
        "Description[ca]": "Exporta les planificacions a fitxers iCalendar",
        "Description[de]": "Exportiert geplante Buchungen in iCalendar-Dateien",
        "Description[en_GB]": "Exports schedules to iCalendar files",
        "Description[eo]": "Eksportas horarojn al iCalendar dosieroj",
        "Description[es]": "Exporta planificaciones a archivos iCalendar",
        "Description[et]": "Ajaplaanide eksport iCalendari failina",
        "Description[eu]": "Esportatu egutegia iCalendar fitxategira",
        "Description[fi]": "Vie aikataulut iCalendar-tiedostoihin",
        "Description[fr]": "Exporte des calendriers dans des fichiers « iCalendar »",
        "Description[gl]": "Exporta planificacións a ficheiros iCalendar",
        "Description[it]": "Esporta le pianificazioni a file iCalendar",
        "Description[ka]": "განრიგის iCalendar-ის ფაილებში გატანა",
        "Description[ko]": "iCalendar 파일로 일정 내보내기",
        "Description[nb]": "Eksporterer tidsplaner til iCalander-filer",
        "Description[nl]": "Exporteert planningen naar iCalender bestanden",
        "Description[pl]": "Eksportuje harmonogramy do plików iCalendar",
        "Description[pt]": "Exporta os agendamentos para ficheiros do iCalendar",
        "Description[pt_BR]": "Exporta agendamentos para arquivos iCalendar",
        "Description[ru]": "Экспортирует планы платежей в файлы iCalendar",
        "Description[sk]": "Exportovať rozvrhy do súborov iCalendar",
        "Description[sl]": "Izvozi časovne plane v datoteke iCalendar",
        "Description[sv]": "Exporterar scheman till iCalendar-filer",
        "Description[tr]": "Zamanlamaları iCalendar dosyalarına dışa aktarır",
        "Description[uk]": "Експортування розкладів до файлів iCalendar",
        "Description[x-test]": "xxExports schedules to iCalendar filesxx",
        "Description[zh_CN]": "将日程表导出为 iCalebdar 文件",
        "Description[zh_TW]": "匯出行程到 iCalendar 檔案",
        "EnabledByDefault": true,
        "Icon": "x-office-calendar",
        "Id": "icalendarexporter",
        "License": "GPL",
        "Name": "iCalendar",
        "Name[ca@valencia]": "iCalendar",
        "Name[ca]": "iCalendar",
        "Name[cs]": "iCalendar",
        "Name[de]": "iCalendar",
        "Name[en_GB]": "iCalendar",
        "Name[eo]": "iCalendar",
        "Name[es]": "iCalendar",
        "Name[et]": "iCalendar",
        "Name[eu]": "iCalendar",
        "Name[fi]": "iCalendar",
        "Name[fr]": "iCalendar",
        "Name[gl]": "iCalendar",
        "Name[ia]": "iCalendar",
        "Name[it]": "iCalendar",
        "Name[ka]": "iCalendar",
        "Name[ko]": "iCalendar",
        "Name[nb]": "iCalendar",
        "Name[nl]": "iCalendar",
        "Name[pl]": "iCalendar",
        "Name[pt]": "iCalendar",
        "Name[pt_BR]": "iCalendar",
        "Name[ru]": "iCalendar",
        "Name[sk]": "iCalendar",
        "Name[sl]": "iCalendar",
        "Name[sv]": "iCalendar",
        "Name[tr]": "iCalendar",
        "Name[uk]": "iCalendar",
        "Name[x-test]": "xxiCalendarxx",
        "Name[zh_CN]": "iCalendar",
        "Name[zh_TW]": "iCalendar",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    },
    "X-KDE-ConfigModule": "kmymoney_plugins/kcms/kcm_icalendarexporter"
}

==> kmymoney-5.2.0.tar.xz: kmymoney-5.2.0/kmymoney/plugins/icalendar/export/icalendarexporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "onet.cristian@gmail.com",
                "Name": "Cristian Oneț",
                "Name[ca@valencia]": "Cristian Oneț",
                "Name[ca]": "Cristian Oneț",
                "Name[cs]": "Cristian Oneț",
                "Name[de]": "Cristian Oneț",
                "Name[en_GB]": "Cristian Oneț",
                "Name[eo]": "Cristian Oneț",
                "Name[es]": "Cristian Oneț",
                "Name[et]": "Cristian Oneț",
                "Name[eu]": "Cristian Oneț",
                "Name[fi]": "Cristian Oneț",
                "Name[fr]": "Cristian Oneț",
                "Name[gl]": "Cristian Oneț",
                "Name[ia]": "Cristian Oneț",
                "Name[it]": "Cristian Oneț",
                "Name[ka]": "Cristian Oneț",
                "Name[ko]": "Cristian Oneț",
                "Name[nb]": "Cristian Oneț",
                "Name[nl]": "Cristian Oneț",
                "Name[pl]": "Cristian Oneț",
                "Name[pt]": "Cristian Oneț",
                "Name[pt_BR]": "Cristian Oneț",
                "Name[ru]": "Cristian Oneț",
                "Name[sk]": "Cristian Oneț",
                "Name[sl]": "Cristian Oneț",
                "Name[sv]": "Cristian Oneț",
                "Name[uk]": "Cristian Oneț",
                "Name[x-test]": "xxCristian Onețxx",
                "Name[zh_CN]": "Cristian Oneț",
                "Name[zh_TW]": "Cristian Oneț"
            }
        ],
        "Description": "Exports schedules to iCalendar files",
        "Description[ca@valencia]": "Exporta les planificacions a fitxers iCalendar",
        "Description[ca]": "Exporta les planificacions a fitxers iCalendar",
        "Description[de]": "Exportiert geplante Buchungen in iCalendar-Dateien",
        "Description[en_GB]": "Exports schedules to iCalendar files",
        "Description[eo]": "Eksportas horarojn al iCalendar dosieroj",
        "Description[es]": "Exporta planificaciones a archivos iCalendar",
        "Description[et]": "Ajaplaanide eksport iCalendari failina",
        "Description[eu]": "Esportatu egutegia iCalendar fitxategira",
        "Description[fi]": "Vie aikataulut iCalendar-tiedostoihin",
        "Description[fr]": "Exporte des calendriers dans des fichiers « iCalendar »",
        "Description[gl]": "Exporta planificacións a ficheiros iCalendar",
        "Description[ia]": "Exporta planos a files de iCalendar",
        "Description[it]": "Esporta le pianificazioni a file iCalendar",
        "Description[ka]": "განრიგის iCalendar-ის ფაილებში გატანა",
        "Description[ko]": "iCalendar 파일로 일정 내보내기",
        "Description[nb]": "Eksporterer tidsplaner til iCalander-filer",
        "Description[nl]": "Exporteert planningen naar iCalender bestanden",
        "Description[pl]": "Eksportuje harmonogramy do plików iCalendar",
        "Description[pt]": "Exporta os agendamentos para ficheiros do iCalendar",
        "Description[pt_BR]": "Exporta agendamentos para arquivos iCalendar",
        "Description[ru]": "Экспортирует планы платежей в файлы iCalendar",
        "Description[sk]": "Exportovať rozvrhy do súborov iCalendar",
        "Description[sl]": "Izvozi časovne plane v datoteke iCalendar",
        "Description[sv]": "Exporterar scheman till iCalendar-filer",
        "Description[uk]": "Експортування розкладів до файлів iCalendar",
        "Description[x-test]": "xxExports schedules to iCalendar filesxx",
        "Description[zh_CN]": "将日程表导出为 iCalebdar 文件",
        "Description[zh_TW]": "匯出行程到 iCalendar 檔案",
        "EnabledByDefault": true,
        "Icon": "x-office-calendar",
        "Id": "icalendarexporter",
        "License": "GPL",
        "Name": "iCalendar",
        "Name[ca@valencia]": "iCalendar",
        "Name[ca]": "iCalendar",
        "Name[cs]": "iCalendar",
        "Name[de]": "iCalendar",
        "Name[en_GB]": "iCalendar",
        "Name[eo]": "iCalendar",
        "Name[es]": "iCalendar",
        "Name[et]": "iCalendar",
        "Name[eu]": "iCalendar",
        "Name[fi]": "iCalendar",
        "Name[fr]": "iCalendar",
        "Name[gl]": "iCalendar",
        "Name[ia]": "iCalendar",
        "Name[it]": "iCalendar",
        "Name[ka]": "iCalendar",
        "Name[ko]": "iCalendar",
        "Name[nb]": "iCalendar",
        "Name[nl]": "iCalendar",
        "Name[pl]": "iCalendar",
        "Name[pt]": "iCalendar",
        "Name[pt_BR]": "iCalendar",
        "Name[ru]": "iCalendar",
        "Name[sk]": "iCalendar",
        "Name[sl]": "iCalendar",
        "Name[sv]": "iCalendar",
        "Name[uk]": "iCalendar",
        "Name[x-test]": "xxiCalendarxx",
        "Name[zh_CN]": "iCalendar",
        "Name[zh_TW]": "iCalendar",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    },
    "X-KDE-ConfigModule": "kmymoney_plugins/kcms/kcm_icalendarexporter"
}
